package init;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;

/**
 * ASAKUSA_HOME/～/bin/～.shをWindowsで呼べるようにする。
 *
 * @author <a
 *         href="http://www.ne.jp/asahi/hishidama/home/tech/asakusafw/install.html"
 *         >hishidama</a>
 * @since 2011.08.05
 * @version 2011.12.04
 */
public class BridgeShell {

	void run() throws IOException {
		String PACK = getClass().getPackage().getName().replace('.', '/') + "/";
		{
			String name = "experimental/bin/hadoop_job_run.sh";
			rename(name);
			delete(name);
			copyResource(PACK + winsh(name), winsh(name));
			copyResource(PACK + "callwinsh.exe", name + ".exe");
		}
		{
			String name = "windgate/bin/finalize.sh";
			rename(name);
			delete(name);
			copyResource(PACK + winsh(name), winsh(name));
			copyResource(PACK + "callwinsh.exe", name + ".exe");
		}
		{
			String name = "windgate/bin/process.sh";
			rename(name);
			delete(name);
			copyResource(PACK + winsh(name), winsh(name));
			copyResource(PACK + "callwinsh.exe", name + ".exe");
		}
	}

	void rename(String name) throws FileNotFoundException {
		File of = asakusaFile(name);
		File nf = asakusaFile(name + ".org");
		if (of.exists() && !nf.exists()) {
			System.out.println("rename: " + of + "\t" + nf);
			boolean success = of.renameTo(nf);
			if (!success) {
				throw new RuntimeException("rename fail: " + of + "\t" + nf);
			}
		}
	}

	void delete(String name) throws FileNotFoundException {
		File f = asakusaFile(name);
		if (f.exists()) {
			System.out.println("delete: " + f);
			boolean success = f.delete();
			if (!success) {
				throw new RuntimeException("delete tail: " + f);
			}
		}
	}

	File asakusaFile(String name) throws FileNotFoundException {
		String home = System.getenv("ASAKUSA_HOME");
		if (home == null || !new File(home).exists()) {
			throw new FileNotFoundException("環境変数ASAKUSA_HOMEが指している場所");
		}
		return new File(home, name);
	}

	String winsh(String name) {
		int n = name.lastIndexOf(".sh");
		return name.substring(0, n) + ".win.sh";
	}

	void copyResource(String src, String dst) throws IOException {
		File d = asakusaFile(dst);
		if (d.exists()) {
			return;
		}
		System.out.println("copy(resource): " + src + "\t" + d);

		ClassLoader loader = getClass().getClassLoader();
		InputStream is = loader.getResourceAsStream(src);
		if (is == null) {
			throw new RuntimeException("not found resource: " + src);
		}
		try {
			// JDK1.7なら簡単なのにー！
			// import java.nio.file.Files;
			// import static java.nio.file.StandardCopyOption.*;
			// try(is = ～) { Files.copy(is, d.toPath(), REPLACE_EXISTING); }

			FileOutputStream os = new FileOutputStream(d);
			try {
				byte[] buf = new byte[1024];
				for (;;) {
					int len = is.read(buf);
					if (len < 0)
						break;
					os.write(buf, 0, len);
				}
			} finally {
				os.close();
			}
		} finally {
			is.close();
		}
	}

	public static void main(String[] args) throws IOException {
		new BridgeShell().run();
	}
}
